@@ -72,10 +72,11 @@ generate_docs <- function() {
 
     api_doc <- readLines(api_doc_file)
 
-    api_doc <- gsub(pattern = "```", replace = "\n```", x = api_doc)
+    api_doc <- gsub(pattern = "knitr```", replace = "knitr\n```", x = api_doc)
     api_doc <- gsub(pattern = "\r", replace = "", x = api_doc)
     api_doc <- gsub(pattern = "[ \t]+\n", replace = "\n", x = api_doc)
     api_doc <- gsub(pattern = "\n\n", replace = "\n", x = api_doc)
+    api_doc <- gsub(pattern = "`:", replace = "`\n>", x = api_doc)
 
     description_doc <- get_description_doc(api_doc)
     function_doc <- get_function_api_doc(name = "execute", text = api_doc)
@@ -100,9 +101,14 @@ build <- function() {
     devtools::check()
 }
 
-build_windows <- function() {
-    print("[build] Running Windows Build")
-    devtools::build_win()
+check_win <- function() {
+    print("[build] Running Check Windows")
+    devtools::check_win_devel()
+}
+
+check_rhub <- function() {
+    print("[build] Running Check r-hub")
+    devtools::check_rhub()
 }
 
 release <- function() {
@@ -186,12 +192,19 @@ get_description_doc <- function(text) {
     print("[build] Extrating Description Documention")
 
     doc <- c()
+    started <- FALSE
     for (line in text) {
-        if (startsWith(x = line, prefix = "# `")) {
-            break
-        }
+        if (started) {
+            if (startsWith(x = line, prefix = "# `")) {
+                break
+            }
 
-        doc <- c(doc, line)
+            doc <- c(doc, line)
+        } else if (startsWith(x = line, prefix = "# DESCRIPTION")) {
+            started <- TRUE
+
+            doc <- c(doc, line)
+        }
     }
 
     doc
@@ -310,7 +323,7 @@ dev_flow <- c(docs_flow, generate_test_code, format, test)
 default_flow <- c(dev_flow, lint, build)
 flows <- list(format = format_flow, dev = dev_flow, development = dev_flow,
     docs = docs_flow, default = default_flow, windows = c(default_flow,
-        build_windows), release = c(default_flow, release))
+        check_win), release = c(default_flow, release))
 
 args <- commandArgs(trailingOnly = TRUE)
 flow_name <- "default"
